==> icebear_v1_4_1.tar: client/help/permission/index.php <==
<?php /**
Application-specific homepage help should not go in this file.
Instead, add it into extensions.php in this directory.
*/?>
<?php
include_once($_SERVER['DOCUMENT_ROOT'].'/client/help/_common/helphead.php');
?>

<h1>Permissions in IceBear</h1>

<p>IceBear has a flexible permissions system that lets you control who can - and cannot - see and change items.</p>
<p>In short:</p>
<ul>
<li>All items are placed into a <a href="../project/">project</a></li>
<li>Users are placed in one or more <a href="../usergroup/">usergroups</a></li>
<li>Usergroups are granted permission to read, modify, create and/or delete within a project</li>
<li>A user's rights on a given record are determined by the project, and by the combined permissions of all the user's groups</li>
<li>Administrators always have permission to see and change anything in IceBear.</li>
</ul>
<h2>Special permissions</h2>
<p>Users may be given additional permissions under certain circumstances.</p> 
<h3>Project owners</h3>
<p>A project owner is the only person (except administrators) who can create and modify proteins within the project, grant and 
revoke usergroups' permissions, and change the project owner.</p>
<p>For more details, see the <a href="../project/">project help</a>.</p>

<h3>Plate owners</h3>
<p>A plate owner can always see a plate and set its protein, regardless of their own permissions. Plates are imported into a
default project, where nobody has any permissions, therefore the plate owner is the only one who can see the plate until it is 
assigned to a real working project. 
<p>For more details, see the <a href="../plate/">plate help</a>.</p>

<?php
include_once($_SERVER['DOCUMENT_ROOT'].'/client/help/_common/helpfoot.php');
?>

==> icebear_v1_11_0.tar: client/help/permission/index.php <==
<?php /**
Application-specific homepage help should not go in this file.
Instead, add it into extensions.php in this directory.
*/?>
<?php
include_once(dirname(__DIR__,3).'/client/help/_common/helphead.php');
?>

<h1>Permissions in IceBear</h1>

<p>IceBear has a flexible permissions system that lets you control who can - and cannot - see and change items.</p>
<p>In short:</p>
<ul>
<li>All items are placed into a <a href="../project/">project</a></li>
<li>Users are placed in one or more <a href="../usergroup/">usergroups</a></li>
<li>Usergroups are granted permission to read, modify, create and/or delete within a project</li>
<li>A user's rights on a given record are determined by the project, and by the combined permissions of all the user's groups</li>
<li>Administrators always have permission to see and change anything in IceBear.</li>
</ul>
<h2>Special permissions</h2>
<p>Users may be given additional permissions under certain circumstances.</p> 
<h3>Project owners</h3>
<p>A project owner is the only person (except administrators) who can create and modify proteins within the project, grant and 
revoke usergroups' permissions, and change the project owner.</p>
<p>For more details, see the <a href="../project/">project help</a>.</p>

<h3>Plate owners</h3>
<p>A plate owner can always see a plate and set its protein, regardless of their own permissions. Plates are imported into a
default project, where nobody has any permissions, therefore the plate owner is the only one who can see the plate until it is 
assigned to a real working project. 
<p>For more details, see the <a href="../plate/">plate help</a>.</p>

<?php
include_once(dirname(__DIR__,3).'/client/help/_common/helpfoot.php');
?>
